    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    %         PawelPaszek, 04/30/03                             %
    %         Function includes system of ODEs describing       %
    %         NF-kB regulatory pathway.                         %
    %         Considered molecular species are coded as         %
    %         follows:                                          %
    %                                                           %  
    %         y(1)   IKKn   neutral                             %    
    %         y(2)   IKKa   active                              %
    %         y(3)   IKKi   inactive                            %
    %         y(4)   (IKKa|IkBa)                                %
    %         y(5)   (IKKa|IkBa|NFkB)                           %
    %         y(6)   NFkB                                       %
    %         y(7)   NFkBn                                      %
    %         y(8)   A20                                        %
    %         y(9)   A20t                                       %
    %         y(10)  IkBa                                       %
    %         y(11)  IkBan                                      %
    %         y(12)  IkBat                                      %      
    %         y(13)  (IkBa|NFkB) cytoplasmic                    %  
    %         y(14)  (IkBan|NFkBn) nuclear                      %
    %                                                           %
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

 function dy=NFmodel(t,y,TR,G1a,G2a,G1,G2)

 NFparameters; %parametrization included in M-file 'NFparameters.m'
 
 %#########################################################################
 %#########################################################################
 %no TNF TR=0, TNF present TR=1
 
 dy=zeros(14,1);
 
 dy(1)=kprod-kdeg*y(1)-TR*k1*y(1);                                                                   %neutral IKK   
 dy(2)=TR*k1*y(1)-k3*y(2)-TR*k2*y(2)*y(8)-kdeg*y(2)-a2*y(2)*y(10)+t1*y(4)-a3*y(2)*y(13)+t2*y(5);     %free active IKK                                                                                    
 dy(3)=k3*y(2)+TR*k2*y(2)*y(8)-kdeg*y(3);                                                            %inactive IKK   
 dy(4)=a2*y(2)*y(10)-t1*y(4);                                                                        %cytoplasmic (IKK|IkBa) complex 
 dy(5)=a3*y(2)*y(13)-t2*y(5);                                                                        %cytoplasmic (IKK|IkBa|NFkB) complex
 dy(6)=c6a*y(13)-a1*y(6)*y(10)+t2*y(5)-i1*y(6);                                                      %free cytoplasmic NFkB
 dy(7)=i1*y(6)-a1*kv*y(11)*y(7);                                                                     %free nuclear NFkB
 dy(8)=c4*y(9)-c5*y(8);                                                                              %cytoplasmic A20
 dy(9)=c2+0.5*c1*(G1+G2)-c3*y(9);                                                                    %A20 transcription
 dy(10)=-a2*y(2)*y(10)-a1*y(10)*y(6)+c4a*y(12)-c5a*y(10)-i1a*y(10)*y(10)/(B*y(13)+y(10))+e1a*y(11);  %free cytoplasmic IkBa
 dy(11)=-a1*kv*y(11)*y(7)+i1a*y(10)*y(10)/(B*y(13)+y(10))-e1a*y(11);                                 %free nuclear IkBan
 dy(12)=c2a+0.5*c1a*(G1a+G2a)-c3a*y(12);                                                             %IkB transcription
 dy(13)=a1*y(10)*y(6)-c6a*y(13)-a3*y(2)*y(13)+e2a*y(14);                                             %cytoplasmic (IkBa|NFkB) complex
 dy(14)=a1*kv*y(11)*y(7)-e2a*y(14);                                                                  %Nuclear (IkBa|NFkB) complex
 