%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%   Pawel Paszek, 09/28/05                                              %
%   In this M-file one can introduce new parameters into the model,     %
%   also diffrent initial conditions and times characterictic for       %
%   simulation can be chosen.                                           %
%                                                                       %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                         W A R N I N G !!!                             % 
%                                                                       %
%   Change of Coefficients in comparison with the deterministic model   % 
%   of the pathway (Lipniacki et al. (2004), JTB 228, 195-215):
% 
% k2 ->k2/1.5,               %inactivation caused by A20, FIT           %  
% i1a->ila*2 = 0.002;        %IkBa nuclear import Hoff, FIT             %
% e1a->ela*2 = 0.001*kv;     %IkBa nuclear export Hoff, FIT             %
%                                                                       %
%                                                                       %
%########################################################################

%############## Simulation time points ##################################
%########################################################################
t000=10*3600;                              %randomization of initial conditions (in seconds)
t00=15*3600;                               %equilibrium waiting time
t0=1*3600;                                 %time when TNF is being introduced into the system
tw=500*60;                                 %length of TNF stimulation
te=500*60;                                 %length of simulation from introducing TNF 

tt=25*3600;                                %time up to which the switching time distribution is derived while waiting for equillibrium
tt1=10*3600;                               %time up to which the switching time distribution is derived while TNF is on
                                           % IMPRTANT -- if these times are too small, it may result in numerical errors
N=1;                                       % Number of cells in the population considered
timeofscatter=[0,15,30,90,150,360]*60;     %time points at which the data for the scatter plots is collected 

%########################################################################
%########################################################################
W0=2*10^-12;            %volume of the cell
V0=5/6*W0;              %volume of the cytoplasm
U0=1/6*W0;              %volume of the nucleus
V=V0;
U=U0;
Av = 6*10^23;
kv=V/U;                 %ratio of cytoplasmic to nuclear volume, kv=5
nscale=U0*Av*10^-6;     %2*10^5  
cscale=V0*Av*10^-6;     %10^6

% %############### Initial conditions for total NF-kB #####################
% %########################################################################
y0=zeros(1,14);         %Initial conditions set to zero for each molecule            
y0(13)=(0.12*10^6);     %NF-kB is given in cytoplasmic complex(IkBa|NFkB)
y0(10)=10^5;            %free cytoplasmic IkBa protein
y0(11)=3*10^3;          %free nuclear IkBa protein
y0(12)=10;              %IkBa mRNA
% %########################################################################
% %########################################################################


%############## Parametrizations for the stochastic part  #################
%##########################################################################
dt=10;                  %simulation step

q1a=1.5*10^-7*U/U0;     %1.5 1/200/nscale NfkB  ataching at IkBa site
q0a=0;                  %1/1000 NfkB constitutive detaching at IkBa site
q2a=10^-6*U/U0;         %1/400/nscale IkBa inducible detaching at IkBa site

q1=1.5*10^-7*U/U0;      %1.5 1/200/nscale NfkB  ataching at A20 site
q0=0;                   % 1/1000 NfkB constitutive detaching at A20 site
q2=10^-6*U/U0;          %1/400/nscale IkBa inducible detaching at A20 site

%%%%%%%%%%%%%  transcription rates %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
c1=0.15;                %0.0000005*kv*60000  inducible A20 mRNA synthesis, Assumption 
c2=0;                   %0.0015 constitutive A20 mRNA synthesis, Assumption
c1a=0.15;               %0.0000005*kv*60000   inducible (linear) IkBa mRNA synthesis FIT
c2a=0;                  %0.0015 constitutive mRNA IkBa synthesis  FIT 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%########################################################################
%############### Parametrization for system of ODE's ####################
%########################################################################

 B=0; %Binding coefficient of Ikba and NFkB used if nonlinear IkBa nuclear import is assumed
%XXXXXXXXXXXXXXXXX A20 XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX                                 
 AB=1;                  %AB=0 corresponds to A20 knokout 
 
 c1=AB*c1;              %AB*0.0000005  inducible A20 mRNA synthesis, Assumption 
 c2=AB*c2;              %AB*0.0  constitutive A20 mRNA synthesis, Assumption
 c3=0.0004;             %0.0004  A20 mRNA degradation rate, Assumption 
 c4=0.5;                %0.5  A20 translation rate, Assumption
 c5=0.0003;             %0.0003  A20 degradation rate, IkBa *5
 
 k1=0.0025;             %0.0025 activation caused by TNF, FIT
 k2=0.1/cscale/2;       %0.1/1.5  inactivation caused by A20, FIT
 k3=0.0015;             %0.0015  spontanouous IKK inactivation,  FIT
 kprod=0.000025*cscale; %0.000025  IKKn production rate
 kdeg=0.000125;         %0.000125  degradation of IKKa,IKKn and IKKi
 %XXXXXXXXXXXXXXXXXXX IkB alpha XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
 a2=0.2/cscale;         %0.2  IKK*IkBa association  Fit
 a1=0.5/cscale;         %0.5  IkBA*NFkB association  Hoff (short, correspond to i1)
 a3=1.0/cscale;         %1.0  IKK*(IkBa|NFkb) association  Fit
 t1=0.1;                %0.1  degradation of (IKK|IkBa)  (any short)
 t2=0.1;                %0.1  degradation of (IKK|IkBa|NFkB)  (any short)
 
 AA=1;                  %%AA=0 corresponds to IkBa knokout)
 
 c1a=AA*c1a;            %AA*0.00005/100  inducible (linear) IkBa mRNA synthesis FIT
 c2a=AA*c2a;            %AA*0.00000  constitutive mRNA IkBa synthesis  FIT 
 c3a=0.0004*1.;         %0.0004  mRNA IkBa degradation, FIT Blattner 22min i.e. 0.00075 
 c4a=0.5;               %0.005*100   IkBa translation rate  FIT 
 c5a=0.0001;            %0.0001  IkBa degradation rate, Pando
 c6a=0.00002;           %0.00002 (IkBa|NFkB) degradation Hoff
 
 i1=0.0025;             %0.0025  NFkB nuclear import, Hoff blue (short correspond to a1)
 e2a=0.01*kv;           %0.01  (IkBa|NFkB) nuclear export, Hoff(any short) blue
 i1a=0.001*2;           %0.001  IkBa nuclear import Hoff, FIT
 e1a=0.0005*kv*2;       %0.0005  IkBa nuclear export Hoff, FIT 
 
 %#########################################################################
 y0(1)=kprod/kdeg;  %initial condition for IKKn corresponding to steady state with no TNF 
 %#########################################################################