%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%   Pawel Paszek 06/15/05                                       %
%   STOCHASTIC SIMULATIONS OF NF-kB PATCHWAY                    %
%                                                               %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
clear;                     %reset all
clc;                       %clear command window
starttime=clock;           %current time
NFparameters;              %loading parameters
YYY=0;                     %matrix of averages of all variables over the time
GG1a=0;GG2a=0;GG1=0;GG2=0; %average status of IkBA 1st, 2nd allele and A20 1st, 2nd allele over the time 
PERIOD=[];                 %stores periods of nuclear NF-kB oscyllations for every single cell considered
NF=[];                     %stores intial NF-kB amount
zzz=size(timeofscatter);   
scatternumb=zzz(2);        %number of time instants for collecting data for scatter plots
YS=zeros(scatternumb,5,N); %3-D matrix storing a data for scatter plots: 1-time points, 2-number variables stored (5 variables), 3- number of cells

for i=1:N                    %beginning the main loop
rand('state',sum(100*clock)) %randomization of the status of random number generator   
i                            %current cell
%############### Initial condition for total NF-kB ######################
% Should be uncommented when simulation distribution of NF-KB in the
% population, otherwise it is included in NFparameters.m
%########################################################################
% y0=zeros(1,14);             %Initial condition set to zero for each molecule            
% y0(13)=(0.06*10^6);         %NF-kB is given in cytoplasmic complex(IkBa|NFkB)
% y0(10)=10^5;%8*10^3;        %free cytoplasmic IkBa protein
% y0(11)=3*10^3;              %free nuclear IkBa protein
% y0(12)=10;                  %IkBa mRNA
%y0(13)=(rand*17+1)*10^4;     %randomization of amount of NF-kB
%########################################################################
%########################################################################

NF=[NF,y0(13)];               % random intial Nf-kB builds vector for all cells
TR=0;                         % TNF off
G1a=0;G2a=0;                  %status of IkBa promoter
G1=0;G2=0;                    %status of A20 promoter
yy0=y0;                       %initial conditions y0(i)
realtime=0;                   %initialized simulation time  
%########################################################################
%%%%%%% minus one step- randomization of initial condition  %%%%%%%%%%%%%
%########################################################################
phase=round(rand*t000/dt)*dt;       %randon initial time (dt -simulation time step -10s)
tspan=[0:dt:tt];                    %length of time for which the solution is derived to find the switching time
while (realtime<t000-phase)
    [T0,Y0]=ode23tb(@NFmodel,tspan,yy0,[],TR,G1a,G2a,G1,G2); 
    Yact=Y0(:,7);                    %amount of NF-kBn  
    Yin=Y0(:,11);                    %amount of IkBan  
    G1ax=G1a;G2ax=G2a;G1x=G1;G2x=G2;
    [mk,G1a,G2a,G1,G2]=statuschange(G1ax,G2ax,G1x,G2x,Yact,Yin);    %function determining the change of gene status
    tc=T0(mk);                       %time when the status changes 
    yy0=Y0(mk,:);                    %transfer of initial conditions to the next iteration  
    realtime=realtime+tc;            %time incrementation
end;

if (realtime>t000-phase)             % correction if the change didn't occure before end of this simulation step
    nn=(realtime-(t000-phase))/dt;
    yy0=Y0(mk-nn,:);
    G1a=G1ax;G2a=G2ax;G1=G1x;G2=G2x;end; 
clear Yact Yin Y0 T0 nn mk phase tc;
%##########################################################################
%%%%%%%%%%%%%%%%%%  zero step - waiting for "equilibrium" %%%%%%%%%%%%%%%%%
%##########################################################################
realtime=0;
while (realtime<t00)
    [T0,Y0]=ode23tb(@NFmodel,tspan,yy0,[],TR,G1a,G2a,G1,G2); 
    Yact=Y0(:,7);                     %amount of NF-kBn  
    Yin=Y0(:,11);                     %amount of IkBan  
    G1ax=G1a;G2ax=G2a;G1x=G1;G2x=G2;
    [mk,G1a,G2a,G1,G2]=statuschange(G1ax,G2ax,G1x,G2x,Yact,Yin);    %function determining the change of gene status
    tc=T0(mk);                        %time when the status changes 
    yy0=Y0(mk,:);                     %transfer of initial conditions to the next iteration
    realtime=realtime+tc;
end;

if (realtime>t00)                     % correction if the change didn't occure before end of this simulation step
    nn=(realtime-t00)/dt;
    yy0=Y0(mk-nn,:);
    G1a=G1ax;G2a=G2ax;G1=G1x;G2=G2x;end;  
clear Yact Yin Y0 T0 nn mk tc; 

%##########################################################################
%%%%%%%%%%%%%%%%%%   first step- no TNF still     %%%%%%%%%%%%%%%%%%%%%%%%%
%##########################################################################
realtime=0;
g1a=[G1a];g2a=[G2a];g1=[G1];g2=[G2];  %stores a single cell gene activity
Y=yy0;                                %stores a single cell variables
T=zeros(1,1);                         %stores simulation time course
while (realtime<t0)
    [T0,Y0]=ode23tb(@NFmodel,tspan,yy0,[],TR,G1a,G2a,G1,G2); 
    Yact=Y0(:,7);                     %amount of NF-kBn  
    Yin=Y0(:,11);                     %amount of IkBan  
    G1ax=G1a;G2ax=G2a;G1x=G1;G2x=G2;
    [mk,G1a,G2a,G1,G2]=statuschange(G1ax,G2ax,G1x,G2x,Yact,Yin);     %function determining the change of gene status

    tc=T0(mk);                        %time when the status changes 
    yy0=Y0(mk,:);                     %transfer of initial conditions to the next iteration
    
    Y=[Y;Y0(2:mk,:)];                 
    T=[T;T0(2:mk)+realtime];
    g1a=[g1a;G1ax*ones(mk-1,1)];g2a=[g2a;G2ax*ones(mk-1,1)];
    g1=[g1;G1x*ones(mk-1,1)];g2=[g2;G2x*ones(mk-1,1)];
    realtime=realtime+tc;
end;
    
if (realtime>t0)                     % correction if the change didn't occure before end of this simulation step
    nn=(realtime-t0)/dt;
    x=size(Y);
    Y=Y(1:(x(1)-nn),:);
    T=T(1:(x(1)-nn));
    yy0=Y0(mk-nn,:);
    x1=length(g1a);
    g1a=g1a(1:x1-nn);g2a=g2a(1:x1-nn);g1=g1(1:x1-nn);g2=g2(1:x1-nn);
    G1a=G1ax;G2a=G2ax;G1=G1x;G2=G2x;end;

%##########################################################################
%%%%%%%%%%%%%%%%%%%%%%%   second step- TNF on   %%%%%%%%%%%%%%%%%%%%%%%%%%%
%##########################################################################

TR=1;                 %TNF on
tspan1=[0:dt:tt1];    %length of time for which the solution is derived to find the switching time
realtime=t0;

while (realtime<t0+tw)
    [T0,Y0]=ode23tb(@NFmodel,tspan1,yy0,[],TR,G1a,G2a,G1,G2); 
    Yact=Y0(:,7);                     %amount of NF-kBn  
    Yin=Y0(:,11);                     %amount of IkBan  
    G1ax=G1a;G2ax=G2a;G1x=G1;G2x=G2;
    [mk,G1a,G2a,G1,G2]=statuschange(G1ax,G2ax,G1x,G2x,Yact,Yin);     %function determining the change of gene status

    tc=T0(mk);                        %time when the status changes 
    yy0=Y0(mk,:);                     %transfer of initial conditions to the next iteration
    
    Y=[Y;Y0(2:mk,:)];                 
    T=[T;T0(2:mk)+realtime];
    g1a=[g1a;G1ax*ones(mk-1,1)];g2a=[g2a;G2ax*ones(mk-1,1)];
    g1=[g1;G1x*ones(mk-1,1)];g2=[g2;G2x*ones(mk-1,1)];
    realtime=realtime+tc;
end;
if (realtime>t0+tw)                   % correction if the change didn't occure before end of this simulation step
    nn=(realtime-t0-tw)/dt;
    x=size(Y);
    Y=Y(1:(x(1)-nn),:);
    T=T(1:(x(1)-nn));
    yy0=Y0(mk-nn,:);
    x1=length(g1a);
    g1a=g1a(1:x1-nn);g2a=g2a(1:x1-nn);g1=g1(1:x1-nn);g2=g2(1:x1-nn);
    G1a=G1ax;G2a=G2ax;G1=G1x;G2=G2x;end;

%##########################################################################
%%%%%%%%%%%%%%%%%%%%%   third step-TNF washed out     %%%%%%%%%%%%%%%%%%%%%
%##########################################################################
TR=0;               %TNF off
realtime=t0+tw;
while (realtime<t0+te)
    [T0,Y0]=ode23tb(@NFmodel,tspan,yy0,[],TR,G1a,G2a,G1,G2); 
    Yact=Y0(:,7);                     %amount of NF-kBn  
    Yin=Y0(:,11);                     %amount of IkBan  
    G1ax=G1a;G2ax=G2a;G1x=G1;G2x=G2;
    [mk,G1a,G2a,G1,G2]=statuschange(G1ax,G2ax,G1x,G2x,Yact,Yin);     %function determining the change of gene status

    tc=T0(mk);                        %time when the status changes 
    yy0=Y0(mk,:);                     %transfer of initial conditions to the next iteration
    
    Y=[Y;Y0(2:mk,:)];                 
    T=[T;T0(2:mk)+realtime];
    g1a=[g1a;G1ax*ones(mk-1,1)];g2a=[g2a;G2ax*ones(mk-1,1)];
    g1=[g1;G1x*ones(mk-1,1)];g2=[g2;G2x*ones(mk-1,1)];
    realtime=realtime+tc;
end;
if (realtime>t0+te)                   % correction if the change didn't occure before end of this simulation step
    nn=(realtime-t0-te)/dt;
    x=size(Y);
    Y=Y(1:(x(1)-nn),:);
    T=T(1:(x(1)-nn));
    yy0=Y0(mk-nn,:);
    x1=length(g1a);
    g1a=g1a(1:x1-nn);g2a=g2a(1:x1-nn);g1=g1(1:x1-nn);g2=g2(1:x1-nn);
    G1a=G1ax;G2a=G2ax;G1=G1x;G2=G2x;end;
%#########################################################################
%############## Extracting the data for the scatters             #########
%#########################################################################
    if (timeofscatter(scatternumb)/3600<=te)
    for j=1:scatternumb
        tindex=(timeofscatter(j)+t0)/dt+1;
        YS(j,1,i)=Y(tindex,7);                                          %1-NfKb
        YS(j,2,i)=Y(tindex,11)+Y(tindex,14)+Y(tindex,10)+Y(tindex,13);  %2-total IkBa
        YS(j,3,i)=Y(tindex,12);                                         %3-IkBa mRNA 
        YS(j,4,i)=Y(tindex,8);                                          %4-A20 protein
        YS(j,5,i)=Y(tindex,9);                                          %5-A20 mRNA 
    end;end;        
 %########################################################################
 %############# Extraxting the periods of the oscylations       ##########
 %########################################################################
 [Per]=findex(T/60,Y(:,7),dt,t0,te);          % call of the findindex function
 PERIOD=[PERIOD;Per];       


YYY=YYY+Y;                                    %variables summed over the cells
GG1a=GG1a+g1a;GG2a=GG2a+g2a;
GG1=GG1+g1;GG2=GG2+g2;
end;                                          %end of the MAIN LOOP

clear tspan tspan1 g1 g2 g1a g2a T0 Y0 Yact Yin Y y0 yy0 tindex;
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%    
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% PLOTS   %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
YYY=YYY/N;                                    %averages over the population
GG1a=GG1a/N;GG2a=GG2a/N;
GG1=GG1/N;GG2=GG2/N;
T=T/3600;

if (N==1)                                     %for nice pictures
    GG1a=GG1a+0.001; GG2a=GG2a+0.001;
    GG1=GG1+0.001;GG2=GG2+0.001;
end;

simulation_time=etime(clock,starttime)        %calculation time in seconds